@@ -71,9 +71,6 @@ class update_properties:
 		return elem
 
 	def update_status(self, elem):
-		if elem['update'] == True:
-			elem['properties']['status']['color'] = elem['color']
-			elem['properties']['status']['name'] = elem['name']
 		return elem
 
 	def update_number(self, elem):
@@ -82,10 +79,6 @@ class update_properties:
 		return elem
 
 	def update_select(self, elem):
-		if elem['update'] == True:
-			if elem['content'] == True:
-				elem['properties']['select']['color'] = elem['color']
-				elem['properties']['select']['name'] = elem['name']
 		return elem
 
 	def update_multi_select(self, elem):
@@ -124,7 +117,10 @@ class update_properties:
 						elem['properties']['people'].append(user)
 		return elem
 
-	def update_properties(self ):
+	def update_last_edited_by(self, elem):
+		return elem
+
+	def update_properties(self):
 		ret = {
 			"title" : self.update_title,
 			"rich_text" : self.update_rich_text,
@@ -136,7 +132,8 @@ class update_properties:
 			"phone_number" : self.update_phone_number,
 			"multi_select" : self.update_multi_select,
 			"people" : self.update_people,
-			# "select" : update_select, Non disponnible pour le moment
-			# "status" : update_status, Non disponnible pour le moment
+			"last_edited_by": self.update_last_edited_by,
+			"select" : self.update_select,
+			"status" : self.update_status,
 		}
 		return ret
